==> delphixpy-1.11.20.0.tar.gz: delphixpy-1.11.20.0/delphixpy/v1_10_6/web/environment/oracle/listener/listener.py <==
#
# Copyright 2023 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "environment.oracle.listener"
"""
from urllib.parse import urlencode
from delphixpy.v1_10_6 import response_validator

def create(engine, oracle_listener=None):
    """
    Create a new OracleListener object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
    :param oracle_listener: Payload object.
    :type oracle_listener: :py:class:`v1_10_6.web.vo.OracleListener`
    :rtype: ``str``
    """
    url = "/resources/json/delphix/environment/oracle/listener"
    response = engine.post(url, oracle_listener.to_dict(dirty=True) if oracle_listener else None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)

def get(engine, ref):
    """
    Retrieve the specified OracleListener object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
    :param ref: Reference to a
        :py:class:`delphixpy.v1_10_6.web.objects.OracleListener.OracleListener`
        object
    :type ref: ``str``
    :rtype: :py:class:`v1_10_6.web.vo.OracleListener`
    """
    url = "/resources/json/delphix/environment/oracle/listener/%s" % ref
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['OracleListener'], returns_list=False, raw_result=raw_result)

def get_all(engine, type=None, environment=None):
    """
    Returns a list of listeners within the environment or the system.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
    :param type: Restrict listeners to type. *(permitted values:
        OracleNodeListener, OracleScanListener)*
    :type type: ``str``
    :param environment: Restrict listeners belonging to the specified
        environment.
    :type environment: ``str``
    :rtype: ``list`` of :py:class:`v1_10_6.web.vo.OracleListener`
    """
    url = "/resources/json/delphix/environment/oracle/listener"
    query_params = {"type": type, "environment": environment}
    query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
    if query_dct:
        url_params = urlencode(query_dct)
        url += "?%s" % url_params
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['OracleListener'], returns_list=True, raw_result=raw_result)

def update(engine, ref, oracle_listener=None):
    """
    Update the specified OracleListener object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
    :param ref: Reference to a
        :py:class:`delphixpy.v1_10_6.web.objects.OracleListener.OracleListener`
        object
    :type ref: ``str``
    :param oracle_listener: Payload object.
    :type oracle_listener: :py:class:`v1_10_6.web.vo.OracleListener`
    """
    url = "/resources/json/delphix/environment/oracle/listener/%s" % ref
    response = engine.post(url, oracle_listener.to_dict(dirty=True) if oracle_listener else None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)

def delete(engine, ref):
    """
    Delete the specified OracleListener object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
    :param ref: Reference to a
        :py:class:`delphixpy.v1_10_6.web.objects.OracleListener.OracleListener`
        object
    :type ref: ``str``
    """
    url = "/resources/json/delphix/environment/oracle/listener/%s/delete" % ref
    response = engine.post(url, None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)

==> delphixpy-1.11.26.0.tar.gz: delphixpy-1.11.26.0/delphixpy/v1_4_3/web/environment/oracle/listener/listener.py <==
#
# Copyright 2023 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "environment.oracle.listener"
"""
from urllib.parse import urlencode
from delphixpy.v1_4_3 import response_validator

def create(engine, oracle_listener=None):
    """
    Create a new OracleListener object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
    :param oracle_listener: Payload object.
    :type oracle_listener: :py:class:`v1_4_3.web.vo.OracleListener`
    :rtype: ``str``
    """
    url = "/resources/json/delphix/environment/oracle/listener"
    response = engine.post(url, oracle_listener.to_dict(dirty=True) if oracle_listener else None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)

def get(engine, ref):
    """
    Retrieve the specified OracleListener object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
    :param ref: Reference to a
        :py:class:`delphixpy.v1_4_3.web.objects.OracleListener.OracleListener`
        object
    :type ref: ``str``
    :rtype: :py:class:`v1_4_3.web.vo.OracleListener`
    """
    url = "/resources/json/delphix/environment/oracle/listener/%s" % ref
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['OracleListener'], returns_list=False, raw_result=raw_result)

def get_all(engine, environment=None, type=None):
    """
    Returns a list of listeners within the environment or the system.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
    :param environment: Restrict listeners belonging to the specified
        environment.
    :type environment: ``str``
    :param type: Restrict listeners to type. *(permitted values:
        OracleNodeListener, OracleScanListener)*
    :type type: ``str``
    :rtype: ``list`` of :py:class:`v1_4_3.web.vo.OracleListener`
    """
    url = "/resources/json/delphix/environment/oracle/listener"
    query_params = {"environment": environment, "type": type}
    query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
    if query_dct:
        url_params = urlencode(query_dct)
        url += "?%s" % url_params
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['OracleListener'], returns_list=True, raw_result=raw_result)

def update(engine, ref, oracle_listener=None):
    """
    Update the specified OracleListener object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
    :param ref: Reference to a
        :py:class:`delphixpy.v1_4_3.web.objects.OracleListener.OracleListener`
        object
    :type ref: ``str``
    :param oracle_listener: Payload object.
    :type oracle_listener: :py:class:`v1_4_3.web.vo.OracleListener`
    """
    url = "/resources/json/delphix/environment/oracle/listener/%s" % ref
    response = engine.post(url, oracle_listener.to_dict(dirty=True) if oracle_listener else None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)

def delete(engine, ref):
    """
    Delete the specified OracleListener object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
    :param ref: Reference to a
        :py:class:`delphixpy.v1_4_3.web.objects.OracleListener.OracleListener`
        object
    :type ref: ``str``
    """
    url = "/resources/json/delphix/environment/oracle/listener/%s/delete" % ref
    response = engine.post(url, None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
